static char *sccsid = "@(#) samples/c/win31/amqsputw.c, samples, p000          1.4  95/11/02 14:05:59";
 /********************************************************************/
 /*                                                                  */
 /* Program name: AMQSPUTW                                           */
 /*                                                                  */
 /* Description: Sample C program, running under Windows 3.X,        */
 /*              that puts messages to a message queue               */
 /*              (example using MQPUT)                               */
 /*                                                                  */
 /*                                                                  */
 /* Statement:   Licensed Materials - Property of IBM                */
 /*                                                                  */
 /*              33H2205, 5622-908                                   */ 
 /*              (C) Copyright IBM Corp. 1994, 1995                  */ 
 /*                                                                  */
 /*                                                                  */
 /********************************************************************/
 /*                                                                  */
 /* Function:                                                        */
 /*                                                                  */
 /*                                                                  */
 /*   AMQSPUTW is a sample C program, running under Microsoft        */
 /*   Windows(*) 3.X, that puts messages on a message                */
 /*   queue, and is an example of the use of MQPUT.                  */
 /*                                                                  */
 /*      -- messages are sent to the queue named by the parameter    */
 /*                                                                  */
 /*      -- gets lines from a file, specified as a command line      */
 /*         argument and adds each to target queue, taking each      */
 /*         line of text as the content of a datagram message;       */
 /*         the sample stops when an EOF is read.                    */
 /*         New-line characters are removed.                         */
 /*         If a line is longer than 99 characters it is broken up   */
 /*         into 99-character pieces. Each piece becomes the         */
 /*         content of a datagram message.                           */
 /*         If the length of a line is a multiple of 99 plus 1       */
 /*         e.g. 199, the last piece will only contain a new-line    */
 /*         character so will terminate the input.                   */
 /*                                                                  */
 /*      -- writes a message to a file specified as a command line   */
 /*         argument, for each MQI reason other than                 */
 /*         MQRC_NONE; stops if there is a MQI completion code       */
 /*         of MQCC_FAILED.                                          */
 /*                                                                  */
 /*    Program logic:                                                */
 /*         Parse and verify command line arguments                  */
 /*         MQCONN to specified Queue Manager                        */
 /*         MQOPEN target queue for OUTPUT                           */
 /*         while end of input file not reached,                     */
 /*         .  read next line of text                                */
 /*         .  MQPUT datagram message with text line as data         */
 /*         MQCLOSE target queue                                     */
 /*         MQDISC from Queue Manager                                */
 /*                                                                  */
 /*                                                                  */
 /********************************************************************/
 /*                                                                  */
 /*   AMQSPUTW has 4 parameters                                      */
 /*                 - the output file name         (required)        */
 /*                 - the input file name          (required)        */
 /*                 - queue manager name           (required)        */
 /*                 - the name of the target queue (optional)        */
 /*                                                                  */
 /********************************************************************/
 /* Trademarks:                                                      */
 /* (*) Windows is a registered trademark of Microsoft Corporation   */
 /********************************************************************/
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
    /* include Windows Header */
 #include <windows.h>
    /* includes for MQI       */
 #include <cmqc.h>


int PASCAL WinMain(HANDLE hInstance,
                   HANDLE hPrevInstance,
                   LPSTR  lpCmdLine,
                   int    nCmdShow)
 {

   /*   Declare file handles for input and output                    */
   FILE    *phInFile;
   FILE    *phOutFile;

   /*   Declare MQI structures needed                                */
   MQOD     od = {MQOD_DEFAULT};    /* Object Descriptor             */
   MQMD     md = {MQMD_DEFAULT};    /* Message Descriptor            */
   MQPMO   pmo = {MQPMO_DEFAULT};   /* put message options           */
      /** note, sample uses defaults where it can **/

   MQHCONN  Hcon;                   /* connection handle             */
   MQHOBJ   Hobj;                   /* object handle                 */
   MQLONG   O_options;              /* MQOPEN options                */
   MQLONG   C_options;              /* MQCLOSE options               */
   MQLONG   CompCode;               /* completion code               */
   MQLONG   OpenCode;               /* MQOPEN completion code        */
   MQLONG   Reason;                 /* reason code                   */
   MQLONG   CReason;                /* reason code for MQCONN        */
   MQLONG   buflen;                 /* buffer length                 */
   char     buffer[100];            /* message buffer                */
   char     QMName[50];             /* queue manager name            */
   char     QName[50];              /* queue name                    */
   char     InFileName[256];        /* Input Data file name          */
   char     OutFileName[256];       /* Output file name              */

   /******************************************************************/
   /*                                                                */
   /*   Parse the command line parameters                            */
   /*                                                                */
   /******************************************************************/
   QMName[0]      = 0;
   QName[0]       = 0;
   InFileName[0]  = 0;
   OutFileName[0] = 0;

   sscanf( lpCmdLine,
           "%s %s %s %s",
           OutFileName,
           InFileName,
           QMName,
           QName );

   /******************************************************************/
   /*                                                                */
   /*   Verify Command Line Parameters and exit                      */
   /*   if mandatory values are not present                          */
   /*                                                                */
   /******************************************************************/
   /*   Output file name...                                          */
   /******************************************************************/
   if ( strlen( OutFileName ) > 0 )
   {
      phOutFile = fopen( OutFileName, "w" );
      if ( phOutFile == NULL )
      {
         exit(99);
      }
   }
   else
   {
      exit(99);
   } /* endif */

   fprintf( phOutFile, "Sample AMQSPUTW start\n");
   fprintf( phOutFile, "Output file \"%s\" opened\n", OutFileName );
   fflush( phOutFile );

   /******************************************************************/
   /*   Input file name...                                           */
   /******************************************************************/
   if ( strlen( InFileName ) > 0 )
   {
      phInFile = fopen( InFileName, "r" );
      if ( phInFile == NULL )
      {
         fprintf( phOutFile, "Input file \"%s\" was not found\n", InFileName );
         fprintf( phOutFile, "Sample AMQSPUTW end\n" );
         exit(99);
      }
   }
   else
   {
      fprintf( phOutFile, "Required parameter missing - input file name\n");
      fprintf( phOutFile, "Required parameters are:\n");
      fprintf( phOutFile, "\tOutput File name\n");
      fprintf( phOutFile, "\tInput File name\n");
      fprintf( phOutFile, "\tQueue Manager name\n");
      fprintf( phOutFile, "\tQueue name (Optional - will use default message queue)\n");
      fprintf( phOutFile, "Sample AMQSPUTW end\n" );
      fflush( phOutFile );
      fclose( phOutFile );
      exit(99);
   } /* endif */

   fprintf( phOutFile, "Input file \"%s\" opened\n", InFileName );
   fflush( phOutFile );

   /******************************************************************/
   /*   MQSeries Queue Manager...                                    */
   /******************************************************************/
   if ( strlen( QMName ) == 0 )
   {
      fprintf( phOutFile, "Required parameter missing - queue name\n");
      fprintf( phOutFile, "Required parameters are:\n");
      fprintf( phOutFile, "\tOutput File name\n");
      fprintf( phOutFile, "\tInput File name\n");
      fprintf( phOutFile, "\tQueue Manager name\n");
      fprintf( phOutFile, "\tQueue name (Optional - will use default message queue)\n");
      fprintf( phOutFile, "Sample AMQSPUTW end\n" );
      fclose( phInFile );
      fclose( phOutFile );
      exit(99);
   }

   fprintf( phOutFile, "Queue Manager \"%s\" will be used\n", QMName );

   if ( strlen( QName ) == 0)
      fprintf( phOutFile, "No parameter for Queue Name. Default Queue Name will be used\n" );
   else
      fprintf( phOutFile, "Queue Name \"%s\" will be used\n", QName );
   fflush( phOutFile );

   /******************************************************************/
   /*                                                                */
   /*   Connect to queue manager                                     */
   /*                                                                */
   /******************************************************************/
   MQCONN(QMName,                  /* queue manager                  */
          &Hcon,                   /* connection handle              */
          &CompCode,               /* completion code                */
          &CReason);               /* reason code                    */

   /* report reason and stop if it failed     */
   if (CompCode == MQCC_FAILED)
   {
     fprintf( phOutFile, "MQCONN ended with reason code %ld\n", CReason);
     fprintf( phOutFile, "Sample AMQSPUTW end\n" );
     fclose( phInFile );
     fclose( phOutFile );
     exit(99);
   }

   /******************************************************************/
   /*                                                                */
   /*   Use parameter as the name of the target queue                */
   /*                                                                */
   /******************************************************************/
   strncpy(od.ObjectName, QName, (int)MQ_Q_NAME_LENGTH);

   /******************************************************************/
   /*                                                                */
   /*   Open the target message queue for output                     */
   /*                                                                */
   /******************************************************************/
   O_options = MQOO_OUTPUT           /* open queue for output        */
           + MQOO_FAIL_IF_QUIESCING; /* but not if MQM stopping      */
   MQOPEN(Hcon,                      /* connection handle            */
          &od,                       /* object descriptor for queue  */
          O_options,                 /* open options                 */
          &Hobj,                     /* object handle                */
          &OpenCode,                 /* MQOPEN completion code       */
          &Reason);                  /* reason code                  */

   /* report reason, if any; stop if failed      */
   if (Reason != MQRC_NONE)
   {
     fprintf( phOutFile, "MQOPEN ended with reason code %ld\n", Reason);
   }

   if (OpenCode == MQCC_FAILED)
   {
     fprintf( phOutFile, "unable to open queue for output\n");
   }

   /******************************************************************/
   /*                                                                */
   /*   Read lines from the file and put them to the message queue   */
   /*   Loop until null line or end of file, or there is a failure   */
   /*                                                                */
   /******************************************************************/
   CompCode = OpenCode;        /* use MQOPEN result for initial test */

   while (CompCode != MQCC_FAILED)
   {
     if (fgets(buffer, sizeof(buffer), phInFile) != NULL)
     {
       buflen = strlen(buffer);       /* length without null         */
       if (buffer[buflen-1] == '\n')  /* last char is a new-line     */
       {
         buffer[buflen-1]  = '\0';    /* replace new-line with null  */
         --buflen;                    /* reduce buffer length        */
       }
     }
     else buflen = 0;        /* treat EOF same as null line          */

     /****************************************************************/
     /*                                                              */
     /*   Put each buffer to the message queue                       */
     /*                                                              */
     /****************************************************************/
     if (buflen > 0)
     {
       memcpy(md.Format,          /* character string format         */
              MQFMT_STRING, (int)MQ_FORMAT_LENGTH);
       MQPUT(Hcon,                /* connection handle               */
             Hobj,                /* object handle                   */
             &md,                 /* message descriptor              */
             &pmo,                /* default options (datagram)      */
             buflen,              /* buffer length                   */
             buffer,              /* message buffer                  */
             &CompCode,           /* completion code                 */
             &Reason);            /* reason code                     */

       /* report reason, if any */
       if (Reason == MQRC_NONE)
       {
          fprintf( phOutFile, "MQPUT OK - message contents: <%s>\n", buffer );
       }
       else
       {
          fprintf( phOutFile, "MQPUT ended with reason code %ld\n", Reason);
       }
     }
     else   /* satisfy end condition when empty line is read */
       CompCode = MQCC_FAILED;
   }

   /******************************************************************/
   /*                                                                */
   /*   Close the target queue (if it was opened)                    */
   /*                                                                */
   /******************************************************************/
   if (OpenCode != MQCC_FAILED)
   {
     C_options = 0;                  /* no close options             */
     MQCLOSE(Hcon,                   /* connection handle            */
             &Hobj,                  /* object handle                */
             C_options,
             &CompCode,              /* completion code              */
             &Reason);               /* reason code                  */

     /* report reason, if any     */
     if (Reason != MQRC_NONE)
     {
       fprintf( phOutFile, "MQCLOSE ended with reason code %ld\n", Reason);
     }
   }

   /******************************************************************/
   /*                                                                */
   /*   Disconnect from MQM if not already connected                 */
   /*                                                                */
   /******************************************************************/
   if (CReason != MQRC_ALREADY_CONNECTED)
   {
     MQDISC(&Hcon,                   /* connection handle            */
            &CompCode,               /* completion code              */
            &Reason);                /* reason code                  */

     /* report reason, if any     */
     if (Reason != MQRC_NONE)
     {
       fprintf( phOutFile, "MQDISC ended with reason code %ld\n", Reason);
     }
   }

   /******************************************************************/
   /*                                                                */
   /*   Clean up open files                                          */
   /*                                                                */
   /******************************************************************/
   fprintf( phOutFile, "Sample AMQSPUTW end\n");
   fclose( phInFile );
   fclose( phOutFile );

   /******************************************************************/
   /*                                                                */
   /* END OF AMQSPUTW                                                */
   /*                                                                */
   /******************************************************************/
   return(0);
 }
