 #if !defined(MQCFC_INCLUDED)          /* File not yet included?      */
   #define MQCFC_INCLUDED              /* Show file now included      */
 /*********************************************************************/
 /*                                                                   */
 /*  Program name:  CMQCFC                                            */
 /*                                                                   */
 /*  Description:   This file declares functions, structures, and     */
 /*                 constants for the IBM Message Queue Interface     */
 /*                 (MQI) in the PC-DOS environment.                  */
 /*                                                                   */
 /*                                                                   */
 /*                                                                   */
 /*  Statement:     Licensed Materials - Property of IBM              */
 /*                                                                   */
 /*                 33H2205, 5622-908                                 */ 
 /*                 (C) Copyright IBM Corp. 1995                      */ 
 /*                                                                   */
 /*                                                                   */
 /*  Status:        Version 2 Release 0.1                             */
 /*                                                                   */
 /*********************************************************************/
 
 #if defined(__cplusplus)
   extern "C" {
 #endif
 
 /*********************************************************************/
 /*  Values Related to MQCFH Structure                                */
 /*********************************************************************/
 
 /* Structure Length */
 #define MQCFH_STRUC_LENGTH 36L
 
 /* Structure Version Number */
 #define MQCFH_VERSION_1 1L
 
 /* Command Codes */
 #define MQCMD_CHANGE_Q_MGR           1L
 #define MQCMD_INQUIRE_Q_MGR          2L
 #define MQCMD_CHANGE_PROCESS         3L
 #define MQCMD_COPY_PROCESS           4L
 #define MQCMD_CREATE_PROCESS         5L
 #define MQCMD_DELETE_PROCESS         6L
 #define MQCMD_INQUIRE_PROCESS        7L
 #define MQCMD_CHANGE_Q               8L
 #define MQCMD_CLEAR_Q                9L
 #define MQCMD_COPY_Q                 10L
 #define MQCMD_CREATE_Q               11L
 #define MQCMD_DELETE_Q               12L
 #define MQCMD_INQUIRE_Q              13L
 #define MQCMD_RESET_Q_STATS          17L
 #define MQCMD_INQUIRE_Q_NAMES        18L
 #define MQCMD_INQUIRE_PROCESS_NAMES  19L
 #define MQCMD_INQUIRE_CHANNEL_NAMES  20L
 #define MQCMD_CHANGE_CHANNEL         21L
 #define MQCMD_COPY_CHANNEL           22L
 #define MQCMD_CREATE_CHANNEL         23L
 #define MQCMD_DELETE_CHANNEL         24L
 #define MQCMD_INQUIRE_CHANNEL        25L
 #define MQCMD_PING_CHANNEL           26L
 #define MQCMD_RESET_CHANNEL          27L
 #define MQCMD_START_CHANNEL          28L
 #define MQCMD_STOP_CHANNEL           29L
 #define MQCMD_START_CHANNEL_INIT     30L
 #define MQCMD_START_CHANNEL_LISTENER 31L
 #define MQCMD_ESCAPE                 38L
 #define MQCMD_RESOLVE_CHANNEL        39L
 #define MQCMD_PING_Q_MGR             40L
 #define MQCMD_INQUIRE_CHANNEL_STATUS 42L
 #define MQCMD_Q_MGR_EVENT            44L
 #define MQCMD_PERFM_EVENT            45L
 #define MQCMD_CHANNEL_EVENT          46L
 
 /* Control Options */
 #define MQCFC_LAST     1L
 #define MQCFC_NOT_LAST 0L
 
 /* Reason Codes */
 #define MQRCCF_CFH_TYPE_ERROR          3001L
 #define MQRCCF_CFH_LENGTH_ERROR        3002L
 #define MQRCCF_CFH_VERSION_ERROR       3003L
 #define MQRCCF_CFH_MSG_SEQ_NUMBER_ERR  3004L
 #define MQRCCF_CFH_CONTROL_ERROR       3005L
 #define MQRCCF_CFH_PARM_COUNT_ERROR    3006L
 #define MQRCCF_CFH_COMMAND_ERROR       3007L
 #define MQRCCF_COMMAND_FAILED          3008L
 #define MQRCCF_CFIN_LENGTH_ERROR       3009L
 #define MQRCCF_CFST_LENGTH_ERROR       3010L
 #define MQRCCF_CFST_STRING_LENGTH_ERR  3011L
 #define MQRCCF_FORCE_VALUE_ERROR       3012L
 #define MQRCCF_STRUCTURE_TYPE_ERROR    3013L
 #define MQRCCF_CFIN_PARM_ID_ERROR      3014L
 #define MQRCCF_CFST_PARM_ID_ERROR      3015L
 #define MQRCCF_MSG_LENGTH_ERROR        3016L
 #define MQRCCF_CFIN_DUPLICATE_PARM     3017L
 #define MQRCCF_CFST_DUPLICATE_PARM     3018L
 #define MQRCCF_PARM_COUNT_TOO_SMALL    3019L
 #define MQRCCF_PARM_COUNT_TOO_BIG      3020L
 #define MQRCCF_Q_ALREADY_IN_CELL       3021L
 #define MQRCCF_Q_TYPE_ERROR            3022L
 #define MQRCCF_MD_FORMAT_ERROR         3023L
 #define MQRCCF_REPLACE_VALUE_ERROR     3025L
 #define MQRCCF_CFIL_DUPLICATE_VALUE    3026L
 #define MQRCCF_CFIL_COUNT_ERROR        3027L
 #define MQRCCF_CFIL_LENGTH_ERROR       3028L
 #define MQRCCF_QUIESCE_VALUE_ERROR     3029L
 #define MQRCCF_MSG_SEQ_NUMBER_ERROR    3030L
 #define MQRCCF_PING_DATA_COUNT_ERROR   3031L
 #define MQRCCF_PING_DATA_COMPARE_ERROR 3032L
 #define MQRCCF_CHANNEL_TYPE_ERROR      3034L
 #define MQRCCF_PARM_SEQUENCE_ERROR     3035L
 #define MQRCCF_XMIT_PROTOCOL_TYPE_ERR  3036L
 #define MQRCCF_BATCH_SIZE_ERROR        3037L
 #define MQRCCF_DISC_INT_ERROR          3038L
 #define MQRCCF_SHORT_RETRY_ERROR       3039L
 #define MQRCCF_SHORT_TIMER_ERROR       3040L
 #define MQRCCF_LONG_RETRY_ERROR        3041L
 #define MQRCCF_LONG_TIMER_ERROR        3042L
 #define MQRCCF_SEQ_NUMBER_WRAP_ERROR   3043L
 #define MQRCCF_MAX_MSG_LENGTH_ERROR    3044L
 #define MQRCCF_PUT_AUTH_ERROR          3045L
 #define MQRCCF_PURGE_VALUE_ERROR       3046L
 #define MQRCCF_CFIL_PARM_ID_ERROR      3047L
 #define MQRCCF_MSG_TRUNCATED           3048L
 #define MQRCCF_CCSID_ERROR             3049L
 #define MQRCCF_ENCODING_ERROR          3050L
 #define MQRCCF_DATA_CONV_VALUE_ERROR   3052L
 #define MQRCCF_INDOUBT_VALUE_ERROR     3053L
 #define MQRCCF_ESCAPE_TYPE_ERROR       3054L
 #define MQRCCF_CHANNEL_TABLE_ERROR     3062L
 #define MQRCCF_MCA_TYPE_ERROR          3063L
 #define MQRCCF_CHL_INST_TYPE_ERROR     3064L
 #define MQRCCF_CHL_STATUS_NOT_FOUND    3065L
 #define MQRCCF_OBJECT_ALREADY_EXISTS   4001L
 #define MQRCCF_OBJECT_WRONG_TYPE       4002L
 #define MQRCCF_LIKE_OBJECT_WRONG_TYPE  4003L
 #define MQRCCF_OBJECT_OPEN             4004L
 #define MQRCCF_ATTR_VALUE_ERROR        4005L
 #define MQRCCF_UNKNOWN_Q_MGR           4006L
 #define MQRCCF_Q_WRONG_TYPE            4007L
 #define MQRCCF_OBJECT_NAME_ERROR       4008L
 #define MQRCCF_ALLOCATE_FAILED         4009L
 #define MQRCCF_HOST_NOT_AVAILABLE      4010L
 #define MQRCCF_CONFIGURATION_ERROR     4011L
 #define MQRCCF_CONNECTION_REFUSED      4012L
 #define MQRCCF_ENTRY_ERROR             4013L
 #define MQRCCF_SEND_FAILED             4014L
 #define MQRCCF_RECEIVED_DATA_ERROR     4015L
 #define MQRCCF_RECEIVE_FAILED          4016L
 #define MQRCCF_CONNECTION_CLOSED       4017L
 #define MQRCCF_NO_STORAGE              4018L
 #define MQRCCF_NO_COMMS_MANAGER        4019L
 #define MQRCCF_LISTENER_NOT_STARTED    4020L
 #define MQRCCF_BIND_FAILED             4024L
 #define MQRCCF_CHANNEL_INDOUBT         4025L
 #define MQRCCF_MQCONN_FAILED           4026L
 #define MQRCCF_MQOPEN_FAILED           4027L
 #define MQRCCF_MQGET_FAILED            4028L
 #define MQRCCF_MQPUT_FAILED            4029L
 #define MQRCCF_PING_ERROR              4030L
 #define MQRCCF_CHANNEL_IN_USE          4031L
 #define MQRCCF_CHANNEL_NOT_FOUND       4032L
 #define MQRCCF_UNKNOWN_REMOTE_CHANNEL  4033L
 #define MQRCCF_REMOTE_QM_UNAVAILABLE   4034L
 #define MQRCCF_REMOTE_QM_TERMINATING   4035L
 #define MQRCCF_MQINQ_FAILED            4036L
 #define MQRCCF_NOT_XMIT_Q              4037L
 #define MQRCCF_CHANNEL_DISABLED        4038L
 #define MQRCCF_USER_EXIT_NOT_AVAILABLE 4039L
 #define MQRCCF_COMMIT_FAILED           4040L
 #define MQRCCF_CHANNEL_ALREADY_EXISTS  4042L
 #define MQRCCF_DATA_TOO_LARGE          4043L
 #define MQRCCF_CHANNEL_NAME_ERROR      4044L
 #define MQRCCF_XMIT_Q_NAME_ERROR       4045L
 #define MQRCCF_MCA_NAME_ERROR          4047L
 #define MQRCCF_SEND_EXIT_NAME_ERROR    4048L
 #define MQRCCF_SEC_EXIT_NAME_ERROR     4049L
 #define MQRCCF_MSG_EXIT_NAME_ERROR     4050L
 #define MQRCCF_RCV_EXIT_NAME_ERROR     4051L
 #define MQRCCF_XMIT_Q_NAME_WRONG_TYPE  4052L
 #define MQRCCF_MCA_NAME_WRONG_TYPE     4053L
 #define MQRCCF_DISC_INT_WRONG_TYPE     4054L
 #define MQRCCF_SHORT_RETRY_WRONG_TYPE  4055L
 #define MQRCCF_SHORT_TIMER_WRONG_TYPE  4056L
 #define MQRCCF_LONG_RETRY_WRONG_TYPE   4057L
 #define MQRCCF_LONG_TIMER_WRONG_TYPE   4058L
 #define MQRCCF_PUT_AUTH_WRONG_TYPE     4059L
 #define MQRCCF_MISSING_CONN_NAME       4061L
 #define MQRCCF_CONN_NAME_ERROR         4062L
 #define MQRCCF_MQSET_FAILED            4063L
 #define MQRCCF_CHANNEL_NOT_ACTIVE      4064L
 #define MQRCCF_TERMINATED_BY_SEC_EXIT  4065L
 #define MQRCCF_DYNAMIC_Q_SCOPE_ERROR   4067L
 #define MQRCCF_CELL_DIR_NOT_AVAILABLE  4068L
 #define MQRCCF_MR_COUNT_ERROR          4069L
 #define MQRCCF_MR_COUNT_WRONG_TYPE     4070L
 #define MQRCCF_MR_EXIT_NAME_ERROR      4071L
 #define MQRCCF_MR_EXIT_NAME_WRONG_TYPE 4072L
 #define MQRCCF_MR_INTERVAL_ERROR       4073L
 #define MQRCCF_MR_INTERVAL_WRONG_TYPE  4074L
 
 
 /*********************************************************************/
 /*  Values Related to MQCFIL Structure                               */
 /*********************************************************************/
 
 /* Structure Length (Fixed Part) */
 #define MQCFIL_STRUC_LENGTH_FIXED 16L
 
 
 /*********************************************************************/
 /*  Values Related to MQCFIN Structure                               */
 /*********************************************************************/
 
 /* Structure Length */
 #define MQCFIN_STRUC_LENGTH 16L
 
 
 /*********************************************************************/
 /*  Values Related to MQCFSL Structure                               */
 /*********************************************************************/
 
 /* Structure Length (Fixed Part) */
 #define MQCFSL_STRUC_LENGTH_FIXED 24L
 
 
 /*********************************************************************/
 /*  Values Related to MQCFST Structure                               */
 /*********************************************************************/
 
 /* Structure Length (Fixed Part) */
 #define MQCFST_STRUC_LENGTH_FIXED 20L
 
 
 /*********************************************************************/
 /*  Values Related to All Structures                                 */
 /*********************************************************************/
 
 /* Structure Type */
 #define MQCFT_COMMAND      1L
 #define MQCFT_RESPONSE     2L
 #define MQCFT_INTEGER      3L
 #define MQCFT_STRING       4L
 #define MQCFT_INTEGER_LIST 5L
 #define MQCFT_STRING_LIST  6L
 #define MQCFT_EVENT        7L
 
 
 /*********************************************************************/
 /*  Values Related to Integer Parameter Structures                   */
 /*********************************************************************/
 
 /* Integer Parameter Types */
 #define MQIACF_FIRST                1001L
 #define MQIACF_Q_MGR_ATTRS          1001L
 #define MQIACF_Q_ATTRS              1002L
 #define MQIACF_PROCESS_ATTRS        1003L
 #define MQIACF_FORCE                1005L
 #define MQIACF_REPLACE              1006L
 #define MQIACF_PURGE                1007L
 #define MQIACF_QUIESCE              1008L
 #define MQIACF_ALL                  1009L
 #define MQIACF_PARAMETER_ID         1012L
 #define MQIACF_ERROR_ID             1013L
 #define MQIACF_ERROR_IDENTIFIER     1013L
 #define MQIACF_SELECTOR             1014L
 #define MQIACF_CHANNEL_ATTRS        1015L
 #define MQIACF_ESCAPE_TYPE          1017L
 #define MQIACF_ERROR_OFFSET         1018L
 #define MQIACF_REASON_QUALIFIER     1020L
 #define MQIACF_COMMAND              1021L
 #define MQIACF_OPEN_OPTIONS         1022L
 #define MQIACF_AUX_ERROR_DATA_INT_1 1070L
 #define MQIACF_AUX_ERROR_DATA_INT_2 1071L
 #define MQIACF_CONV_REASON_CODE     1072L
 #define MQIACF_LAST_USED            1072L
 
 #define MQIACH_FIRST                   1501L
 #define MQIACH_XMIT_PROTOCOL_TYPE      1501L
 #define MQIACH_BATCH_SIZE              1502L
 #define MQIACH_DISC_INTERVAL           1503L
 #define MQIACH_SHORT_TIMER             1504L
 #define MQIACH_SHORT_RETRY             1505L
 #define MQIACH_LONG_TIMER              1506L
 #define MQIACH_LONG_RETRY              1507L
 #define MQIACH_PUT_AUTHORITY           1508L
 #define MQIACH_SEQUENCE_NUMBER_WRAP    1509L
 #define MQIACH_MAX_MSG_LENGTH          1510L
 #define MQIACH_CHANNEL_TYPE            1511L
 #define MQIACH_DATA_COUNT              1512L
 #define MQIACH_MSG_SEQUENCE_NUMBER     1514L
 #define MQIACH_DATA_CONVERSION         1515L
 #define MQIACH_IN_DOUBT                1516L
 #define MQIACH_MCA_TYPE                1517L
 #define MQIACH_CHANNEL_INSTANCE_TYPE   1523L
 #define MQIACH_CHANNEL_INSTANCE_ATTRS  1524L
 #define MQIACH_CHANNEL_ERROR_DATA      1525L
 #define MQIACH_CHANNEL_TABLE           1526L
 #define MQIACH_CHANNEL_STATUS          1527L
 #define MQIACH_INDOUBT_STATUS          1528L
 #define MQIACH_LAST_SEQUENCE_NUMBER    1529L
 #define MQIACH_CURRENT_MSGS            1531L
 #define MQIACH_CURRENT_SEQUENCE_NUMBER 1532L
 #define MQIACH_MSGS                    1534L
 #define MQIACH_BYTES_SENT              1535L
 #define MQIACH_BYTES_RECEIVED          1536L
 #define MQIACH_BATCHES                 1537L
 #define MQIACH_BUFFERS_SENT            1538L
 #define MQIACH_BUFFERS_RECEIVED        1539L
 #define MQIACH_LONG_RETRIES_LEFT       1540L
 #define MQIACH_SHORT_RETRIES_LEFT      1541L
 #define MQIACH_MCA_STATUS              1542L
 #define MQIACH_STOP_REQUESTED          1543L
 #define MQIACH_MR_COUNT                1544L
 #define MQIACH_MR_INTERVAL             1545L
 #define MQIACH_LAST_USED               1545L
 
 
 /*********************************************************************/
 /*  Values Related to Character Parameter Structures                 */
 /*********************************************************************/
 
 /* Character Parameter Types */
 #define MQCACF_FIRST                   3001L
 #define MQCACF_FROM_Q_NAME             3001L
 #define MQCACF_TO_Q_NAME               3002L
 #define MQCACF_FROM_PROCESS_NAME       3003L
 #define MQCACF_TO_PROCESS_NAME         3004L
 #define MQCACF_FROM_CHANNEL_NAME       3007L
 #define MQCACF_TO_CHANNEL_NAME         3008L
 #define MQCACF_Q_NAMES                 3011L
 #define MQCACF_PROCESS_NAMES           3012L
 #define MQCACF_ESCAPE_TEXT             3014L
 #define MQCACF_LOCAL_Q_NAMES           3015L
 #define MQCACF_MODEL_Q_NAMES           3016L
 #define MQCACF_ALIAS_Q_NAMES           3017L
 #define MQCACF_REMOTE_Q_NAMES          3018L
 #define MQCACF_SENDER_CHANNEL_NAMES    3019L
 #define MQCACF_SERVER_CHANNEL_NAMES    3020L
 #define MQCACF_REQUESTER_CHANNEL_NAMES 3021L
 #define MQCACF_RECEIVER_CHANNEL_NAMES  3022L
 #define MQCACF_OBJECT_Q_MGR_NAME       3023L
 #define MQCACF_APPL_NAME               3024L
 #define MQCACF_USER_IDENTIFIER         3025L
 #define MQCACF_AUX_ERROR_DATA_STR_1    3026L
 #define MQCACF_AUX_ERROR_DATA_STR_2    3027L
 #define MQCACF_AUX_ERROR_DATA_STR_3    3028L
 #define MQCACF_LAST_USED               3028L
 
 #define MQCACH_FIRST               3501L
 #define MQCACH_CHANNEL_NAME        3501L
 #define MQCACH_DESC                3502L
 #define MQCACH_MODE_NAME           3503L
 #define MQCACH_TP_NAME             3504L
 #define MQCACH_XMIT_Q_NAME         3505L
 #define MQCACH_CONNECTION_NAME     3506L
 #define MQCACH_MCA_NAME            3507L
 #define MQCACH_SEC_EXIT_NAME       3508L
 #define MQCACH_MSG_EXIT_NAME       3509L
 #define MQCACH_SEND_EXIT_NAME      3510L
 #define MQCACH_RCV_EXIT_NAME       3511L
 #define MQCACH_CHANNEL_NAMES       3512L
 #define MQCACH_SEC_EXIT_USER_DATA  3513L
 #define MQCACH_MSG_EXIT_USER_DATA  3514L
 #define MQCACH_SEND_EXIT_USER_DATA 3515L
 #define MQCACH_RCV_EXIT_USER_DATA  3516L
 #define MQCACH_USER_ID             3517L
 #define MQCACH_PASSWORD            3518L
 #define MQCACH_LAST_MSG_TIME       3524L
 #define MQCACH_LAST_MSG_DATE       3525L
 #define MQCACH_MCA_USER_ID         3527L
 #define MQCACH_CHANNEL_START_TIME  3528L
 #define MQCACH_CHANNEL_START_DATE  3529L
 #define MQCACH_MCA_JOB_NAME        3530L
 #define MQCACH_LAST_LUWID          3531L
 #define MQCACH_CURRENT_LUWID       3532L
 #define MQCACH_FORMAT_NAME         3533L
 #define MQCACH_MR_EXIT_NAME        3534L
 #define MQCACH_MR_EXIT_USER_DATA   3535L
 #define MQCACH_LAST_USED           3535L
 
 
 /*********************************************************************/
 /*  Parameter Values                                                 */
 /*********************************************************************/
 
 /* Indoubt Status */
 #define MQCHIDS_NOT_INDOUBT 0L
 #define MQCHIDS_INDOUBT     1L
 
 /* Channel Status */
 #define MQCHS_BINDING    1L
 #define MQCHS_STARTING   2L
 #define MQCHS_RUNNING    3L
 #define MQCHS_STOPPING   4L
 #define MQCHS_RETRYING   5L
 #define MQCHS_STOPPED    6L
 #define MQCHS_REQUESTING 7L
 #define MQCHS_PAUSED     8L
 
 /* Channel Stop Option */
 #define MQCHSR_STOP_NOT_REQUESTED 0L
 #define MQCHSR_STOP_REQUESTED     1L
 
 /* Channel Table Type */
 #define MQCHTAB_Q_MGR    1L
 #define MQCHTAB_CLNTCONN 2L
 
 /* Escape Type */
 #define MQET_MQSC 1L
 
 /* Event Recording */
 #define MQEVR_DISABLED 0L
 #define MQEVR_ENABLED  1L
 
 /* Force Option */
 #define MQFC_YES 1L
 #define MQFC_NO  0L
 
 /* Indoubt Option */
 #define MQIDO_COMMIT  1L
 #define MQIDO_BACKOUT 2L
 
 /* Message Channel Agent Status */
 #define MQMCAS_STOPPED 0L
 #define MQMCAS_RUNNING 3L
 
 /* Purge Option */
 #define MQPO_YES 1L
 #define MQPO_NO  0L
 
 /* Quiesce Option */
 #define MQQO_YES 1L
 #define MQQO_NO  0L
 
 /* Queue Service-Interval Events */
 #define MQQSIE_NONE 0L
 #define MQQSIE_HIGH 1L
 #define MQQSIE_OK   2L
 
 /* Replace Option */
 #define MQRP_YES 1L
 #define MQRP_NO  0L
 
 /* Reason Qualifiers */
 #define MQRQ_CONN_NOT_AUTHORIZED      1L
 #define MQRQ_OPEN_NOT_AUTHORIZED      2L
 #define MQRQ_CLOSE_NOT_AUTHORIZED     3L
 #define MQRQ_CMD_NOT_AUTHORIZED       4L
 #define MQRQ_Q_MGR_STOPPING           5L
 #define MQRQ_Q_MGR_QUIESCING          6L
 #define MQRQ_CHANNEL_STOPPED_OK       7L
 #define MQRQ_CHANNEL_STOPPED_ERROR    8L
 #define MQRQ_CHANNEL_STOPPED_RETRY    9L
 #define MQRQ_CHANNEL_STOPPED_DISABLED 10L
 
 /* Queue Definition Scope */
 #define MQSCO_Q_MGR 1L
 #define MQSCO_CELL  2L
 
 
 /*********************************************************************/
 /*  MQCFH Structure                                                  */
 /*********************************************************************/
 
 typedef struct tagMQCFH {
   MQLONG  Type;            /* Structure type */
   MQLONG  StrucLength;     /* Structure length */
   MQLONG  Version;         /* Structure version number */
   MQLONG  Command;         /* Command identifier */
   MQLONG  MsgSeqNumber;    /* Message sequence number */
   MQLONG  Control;         /* Control options */
   MQLONG  CompCode;        /* Completion code */
   MQLONG  Reason;          /* Reason code qualifying completion code */
   MQLONG  ParameterCount;  /* Count of parameter structures */
  } MQCFH;
 typedef MQCFH MQPOINTER PMQCFH;
 
 #define MQCFH_DEFAULT MQCFT_COMMAND,\
                       MQCFH_STRUC_LENGTH,\
                       MQCFH_VERSION_1,\
                       0L,\
                       1L,\
                       MQCFC_LAST,\
                       MQCC_OK,\
                       MQRC_NONE,\
                       0L
 
 
 /*********************************************************************/
 /*  MQCFIL Structure                                                 */
 /*********************************************************************/
 
 typedef struct tagMQCFIL {
   MQLONG  Type;         /* Structure type */
   MQLONG  StrucLength;  /* Structure length */
   MQLONG  Parameter;    /* Parameter identifier */
   MQLONG  Count;        /* Count of parameter values */
   MQLONG  Values[1];    /* Parameter values - first element */
  } MQCFIL;
 typedef MQCFIL MQPOINTER PMQCFIL;
 
 #define MQCFIL_DEFAULT MQCFT_INTEGER_LIST,\
                        MQCFIL_STRUC_LENGTH_FIXED,\
                        0L,\
                        0L,\
                        {0L}
 
 
 /*********************************************************************/
 /*  MQCFIN Structure                                                 */
 /*********************************************************************/
 
 typedef struct tagMQCFIN {
   MQLONG  Type;         /* Structure type */
   MQLONG  StrucLength;  /* Structure length */
   MQLONG  Parameter;    /* Parameter identifier */
   MQLONG  Value;        /* Parameter value */
  } MQCFIN;
 typedef MQCFIN MQPOINTER PMQCFIN;
 
 #define MQCFIN_DEFAULT MQCFT_INTEGER,\
                        MQCFIN_STRUC_LENGTH,\
                        0L,\
                        0L
 
 
 /*********************************************************************/
 /*  MQCFSL Structure                                                 */
 /*********************************************************************/
 
 typedef struct tagMQCFSL {
   MQLONG  Type;            /* Structure type */
   MQLONG  StrucLength;     /* Structure length */
   MQLONG  Parameter;       /* Parameter identifier */
   MQLONG  CodedCharSetId;  /* Coded character set identifier */
   MQLONG  Count;           /* Count of parameter values */
   MQLONG  StringLength;    /* Length of one string */
   MQCHAR  Strings[1];      /* String values - first character */
  } MQCFSL;
 typedef MQCFSL MQPOINTER PMQCFSL;
 
 #define MQCFSL_DEFAULT MQCFT_STRING_LIST,\
                        MQCFSL_STRUC_LENGTH_FIXED,\
                        0L,\
                        MQCCSI_DEFAULT,\
                        0L,\
                        0L,\
                        {""}
 
 
 /*********************************************************************/
 /*  MQCFST Structure                                                 */
 /*********************************************************************/
 
 typedef struct tagMQCFST {
   MQLONG  Type;            /* Structure type */
   MQLONG  StrucLength;     /* Structure length */
   MQLONG  Parameter;       /* Parameter identifier */
   MQLONG  CodedCharSetId;  /* Coded character set identifier */
   MQLONG  StringLength;    /* Length of string */
   MQCHAR  String[1];       /* String value - first character */
  } MQCFST;
 typedef MQCFST MQPOINTER PMQCFST;
 
 #define MQCFST_DEFAULT MQCFT_STRING,\
                        MQCFST_STRUC_LENGTH_FIXED,\
                        0L,\
                        MQCCSI_DEFAULT,\
                        0L,\
                        {""}
 
 
 #if defined(__cplusplus)
   }
 #endif
 
 #endif  /* End of header file */
